import aiohttp
import asyncio

from huibiao_framework.client.data_model.vllm import HuizeQwen32bAwqVo
from huibiao_framework.client.llm.huize_qwen32b_awq_client import HuiZeQwen32bQwqClient


async def main():
    async with aiohttp.ClientSession() as session:
        client = HuiZeQwen32bQwqClient(session)
        resp1: HuizeQwen32bAwqVo = await client.query("今天天气如何")
        return resp1.result.Output


async def test():
    """
    并行
    """
    result = await asyncio.gather(*[main(), main(), main()])
    print(result)


if __name__ == "__main__":
    asyncio.run(test())



from typing import List, Optional

from pydantic import BaseModel, field_validator
from huibiao_framework.execption.model import Qwen32bAwqResponseFormatError


class HuizeQwen32bAwqDto(BaseModel):
    class Message(BaseModel):
        content: str = "今天天气如何"
        role: str = "user"

    Action: str = "NormalChat"
    Messages: List[Message] = [
        Message(),
    ]


class HuizeQwen32bAwqVo(BaseModel):
    Output: Optional[str]
    TokenProbs: Optional[List[float]]

    @field_validator("Output")
    def check_output_not_empty(cls, v: str) -> str:
        if v is None or not v.strip():
            raise Qwen32bAwqResponseFormatError("Field 'result.Output' is Empty")
        return v



from enum import Enum
from typing import Optional, Union

from pydantic import BaseModel


class ProgressSend:
    class AnalysisType(str, Enum):
        """分析类型枚举"""

        ANALYZE = "analyze"  # 智析
        COMPARE = "compare"  # 相似比较
        DIFF_COMPARE = "diffCompare"  # 差异比较
        INQUIRE = "inquire"  # 智查
        WRITE = "write"  # 智写

    class Dto(BaseModel):
        progress: Union[str, int] = "100"  # 当前步骤的进度, 百分数%
        step: str
        ratio: Union[str, int]  # 该步骤占整体进度的比值，百分数%
        type: Optional["ProgressSend.AnalysisType"] = None
        projectId: Union[str, int] = ""
        recordId: Union[str, int] = ""

    class Vo(BaseModel):
        """API响应视图对象"""

        code: str = ""
        reason: str = ""
        message: str = ""
        referenceError: str = ""
